==> testcafe-14.1.3.tgz: package/hammerhead/lib/processed_js_cache.js <==
var Crypto = require("crypto");

var ProcessedJSCache = module.exports = function() {
    this.items = {};
    this.size = 0;
};

ProcessedJSCache.MAX_SIZE = 50 * 1024 * 1024;

ProcessedJSCache.CLEAN_UP_DEST_SIZE = Math.round(ProcessedJSCache.MAX_SIZE / 2);

ProcessedJSCache.prototype._cleanUp = function() {
    var cache = this;
    var lruOrdered = Object.keys(this.items).map(function(digest) {
        return {
            digest: digest,
            lastUse: cache.items[digest].lastUse
        };
    }).sort(function(a, b) {
        return a.lastUse > b.lastUse ? 1 : -1;
    });
    for (var i = 0; i < lruOrdered.length; i++) {
        var digest = lruOrdered[i].digest;
        cache.size -= cache.items[digest].size;
        delete cache.items[digest];
        if (cache.size <= ProcessedJSCache.CLEAN_UP_DEST_SIZE) {
            break;
        }
    }
};

ProcessedJSCache.prototype.add = function(js, processedJs) {
    var cache = this, lastUse = new Date().getTime();
    process.nextTick(function() {
        var hash = Crypto.createHash("md5");
        hash.update(js);
        var digest = hash.digest("hex"), size = processedJs.length;
        cache.size += size;
        cache.items[digest] = {
            data: processedJs,
            size: size,
            lastUse: lastUse
        };
        if (cache.size > ProcessedJSCache.MAX_SIZE) {
            cache._cleanUp();
        }
    });
};

ProcessedJSCache.prototype.pick = function(js) {
    var hash = Crypto.createHash("md5");
    hash.update(js);
    var digest = hash.digest("hex");
    var cacheItem = this.items[digest];
    if (cacheItem) {
        cacheItem.lastUse = new Date().getTime();
        return cacheItem.data;
    }
    return null;
};

==> testcafe-15.1.316987.tgz: package/hammerhead/lib/processed_js_cache.js <==
var Crypto = require("crypto");

var ProcessedJSCache = module.exports = function() {
    this.items = {};
    this.size = 0;
};

ProcessedJSCache.MAX_SIZE = 50 * 1024 * 1024;

ProcessedJSCache.CLEAN_UP_DEST_SIZE = Math.round(ProcessedJSCache.MAX_SIZE / 2);

ProcessedJSCache.prototype._cleanUp = function() {
    var cache = this;
    var lruOrdered = Object.keys(this.items).map(function(digest) {
        return {
            digest: digest,
            lastUse: cache.items[digest].lastUse
        };
    }).sort(function(a, b) {
        return a.lastUse > b.lastUse ? 1 : -1;
    });
    for (var i = 0; i < lruOrdered.length; i++) {
        var digest = lruOrdered[i].digest;
        cache.size -= cache.items[digest].size;
        delete cache.items[digest];
        if (cache.size <= ProcessedJSCache.CLEAN_UP_DEST_SIZE) break;
    }
};

ProcessedJSCache.prototype.add = function(js, processedJs) {
    var cache = this, lastUse = new Date().getTime();
    setTimeout(function() {
        var hash = Crypto.createHash("md5");
        hash.update(js);
        var digest = hash.digest("hex"), size = processedJs.length;
        cache.size += size;
        cache.items[digest] = {
            data: processedJs,
            size: size,
            lastUse: lastUse
        };
        if (cache.size > ProcessedJSCache.MAX_SIZE) cache._cleanUp();
    });
};

ProcessedJSCache.prototype.pick = function(js) {
    var hash = Crypto.createHash("md5");
    hash.update(js);
    var digest = hash.digest("hex");
    var cacheItem = this.items[digest];
    if (cacheItem) {
        cacheItem.lastUse = new Date().getTime();
        return cacheItem.data;
    }
    return null;
};
